@@ -1,6 +1,6 @@
 context("h5 : setSimulationPathH5")
 
-if(requireNamespace("rhdf5") & .runThisTest){
+if(.requireRhdf5_Antares(stopP = FALSE) & .runH5Test){
   test_that("h5 : identical setSimulationPathH5", {
     identical(setSimulationPathH5(tpDir), setSimulationPathH5(tpDir, 1))
     expect_identical(setSimulationPathH5(tpDir), setSimulationPathH5(tpDir, 1))
